pub trait FileTypeExt {
// Required methods
fn is_block_device(&self) -> bool;
fn is_char_device(&self) -> bool;
fn is_fifo(&self) -> bool;
fn is_socket(&self) -> bool;
}Expand description
Unix-specific extensions for FileType.
This corresponds to std::os::unix::fs::FileTypeExt.
Required Methods
Sourcefn is_block_device(&self) -> bool
fn is_block_device(&self) -> bool
Returns true if this file type is a block device.
Sourcefn is_char_device(&self) -> bool
fn is_char_device(&self) -> bool
Returns true if this file type is a character device.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl FileTypeExt for FileType
Available on Unix or VxWorks only.