pub struct UnixStream { /* private fields */ }Expand description
A Unix stream socket.
This corresponds to async_std::os::unix::net::UnixStream.
This UnixStream has no connect method. To create a UnixStream, first
obtain a Dir containing the path, and then call
Dir::connect_unix_stream.
Implementations
Sourceimpl UnixStream
impl UnixStream
Sourcepub fn from_std(std: UnixStream) -> Self
pub fn from_std(std: UnixStream) -> Self
Constructs a new instance of Self from the given
async_std::os::unix::net::UnixStream.
This grants access the resources the
async_std::os::unix::net::UnixStream instance already has access
to.
Sourcepub fn pair() -> Result<(Self, Self)>
pub fn pair() -> Result<(Self, Self)>
Creates an unnamed pair of connected sockets.
This corresponds to async_std::os::unix::net::UnixStream::pair.
TODO: should this require a capability?
Sourcepub fn local_addr(&self) -> Result<SocketAddr>
pub fn local_addr(&self) -> Result<SocketAddr>
Returns the socket address of the local half of this connection.
This corresponds to
async_std::os::unix::net::UnixStream::local_addr.
Sourcepub fn peer_addr(&self) -> Result<SocketAddr>
pub fn peer_addr(&self) -> Result<SocketAddr>
Returns the socket address of the remote half of this connection.
This corresponds to
async_std::os::unix::net::UnixStream::peer_addr.